/*
Connect4 game entry point and main menu handling.


Copyright (c) 2021 Marco's Retrobits

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

// Build standard I/O version for ZX Spectrum:
// zcc +zx -vn -startup=1 -clib=sdcc_iy -lm Connect4.c game.c io.c -o Connect4 -create-app
// Build standard I/O version for CP/M:
// zcc +cpm -vn -clib=sdcc_iy -lm Connect4.c game.c io.c -o Connect4 -create-app

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "game.h"
#include "io.h"

void main()
{
    init();

	// The first player (0 or 1) dropping a disc in current match.
	uint8_t firstPlayer = 0;

	while (true)
	{
		uint8_t choice = doMenu(firstPlayer);
		switch (choice)
		{
		case 1:
			// Start game
			game(firstPlayer);
			firstPlayer = 1 - firstPlayer;
			break;
		case 2:
			// Player 0 type
			player_types[0] = 1 - player_types[0];
			break;
		case 3:
			// Player 1 type
			player_types[1] = 1 - player_types[1];
			break;
        case 4:
			// First player
            firstPlayer = 1 - firstPlayer;
            break;
		case 5:
			// Reset stats
			drawGames = 0;
			wins[0] = 0;
			wins[1] = 0;
			totalMoves = 0;
			break;
		default:
			break;
		}
	}
}
