/*
Connect4 game engine function declarations and macro definitions.

Copyright (c) 2021 Marco's Retrobits

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

#pragma once

#include <stdint.h>

// Board height
#define ROWS 6
// Board width
#define COLS 7
// Target line length
#define LINELEN 4
// Character defining an empty board cell
#define EMPTY ' '

#define GAME_STATUS_DRAW		2
#define GAME_STATUS_NOT_OVER	3

#define PLAYER_TYPE_HUMAN		0
#define PLAYER_TYPE_COMPUTER	1

/// <summary>
/// Player types (human, computer)
/// </summary>
extern uint8_t player_types[2];

/// <summary>
/// Wins counters by player (for statistics).
/// </summary>
extern uint16_t wins[2];
/// <summary>
/// Draw games counter (for statistics).
/// </summary>
extern uint16_t drawGames;
/// <summary>
/// Total moves counter (for statistics).
/// </summary>
extern uint32_t totalMoves;

/// <summary>
/// The game board.
/// Each cell can be either EMPTY (' ') or occupied by one of the players discs ('0' or '1').
/// </summary>
extern char board[ROWS][COLS];

/// <summary>
/// The main game function. Implements a match.
/// </summary>
void game(uint8_t firstPlayer);

