/*
Simple Connect4 UI implementation based on standard console I/O.

Copyright (c) 2021 Marco's Retrobits

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

#include <stdint.h>
#include <stdio.h>
#include "game.h"

void init(void)
{
	// Nothing to do here!
}

void flushInput(void)
{
	int c;
	while ((c = getchar()) != '\n' && c != EOF);
}

void printBoard(void)
{
	printf("\n");
	for (int r = 0; r < ROWS; r++)
	{
		printf("|");
		for (int c = 0; c < COLS; c++)
		{
			printf("%c|", board[r][c]);
		}
		printf("\n");
	}
	printf("---------------\n");
	printf("|");
	for (int i = 0; i < COLS; i++)
	{
		printf("%d|", i + 1);
	}
	printf("\n");
	printf("\n");
}

void updateBoard(uint8_t player, uint8_t col, uint8_t row)
{
	printBoard();
}

void printWinner(uint8_t winner, uint8_t moves)
{
	printf("Player %d wins in %d moves.\n", winner, moves);
}

void printDraw(void)
{
	printf("Draw game.\n");
}

uint8_t promptColumn(uint8_t player)
{
	int c = '0';

	printf("Input player %d: ", player);

	while (c < '1' || c > '7')
	{
		c = getchar();
	}
	flushInput();

	return (uint8_t)(c - '1');
}

void printMove(uint8_t player, uint8_t col)
{
	printf("Player %d move: %d\n", player, col + 1);
}

void printThinking(uint8_t player)
{
	printf("Player %d thinking...\n", player);
}

void printPlayerType(uint8_t playerType)
{
	printf("%s\n", playerType == PLAYER_TYPE_HUMAN ? "HUMAN" : "COMPUTER");
}

uint8_t doMenu(uint8_t firstPlayer)
{
	printf("\nConnect4 by Marco's Retrobits\nhttps://retrobits.itch.io\n\n");

	uint16_t totalGames = drawGames + wins[0] + wins[1];
	printf("Total games: %d\n", drawGames + wins[0] + wins[1]);
	printf("Player 0 wins: %d\n", wins[0]);
	printf("Player 1 wins: %d\n", wins[1]);
	printf("Draw games: %d\n", drawGames);
	printf("Average moves per match: %d\n\n", totalGames == 0 ? 0 : totalMoves / totalGames);

	printf("1 Start game\n");
	printf("2 Player 0 type: ");
	printPlayerType(player_types[0]);
	printf("3 Player 1 type: ");
	printPlayerType(player_types[1]);
	printf("4 First player: Player %d\n", firstPlayer);
	printf("5 Reset stats\n\n");

	int c = '0';

	while (c < '1' || c > '5')
	{
		c = getchar();
	}
	flushInput();

	return (uint8_t)(c - '0');
}

